<?php 
    $title = "Error Bands and Confidence Intervals";
    // $plotTargets = array('chart1', 'chart2', 'chart3', 'chart4');
?>
<?php include "opener.php"; ?>

<!-- Example scripts go here -->
<p>Bands (like confidence intervals or error bands) can be added to line charts through the "bands" option of the line renderer.  The band data can be automatically computed or manually assigned.  If assigned manually, the simpliest approach is to set the "rendererOptions: { bandData: [] }" array on the series.  Note that band data is taken into account when axes scale themselves so bands will not get clipped.</p>


<p>Band data can be supplied as arrays of [x,y] values.  One array for the upper band line and one for the lower band line.</p>

 <div id="chart01" style="height:300px; width:600px;"></div>
    <pre class="code brush:js"></pre>


<p>The number of points in the band data arrays does not have to correspond to the number of points in the data series.  Also, band data will be drawn as smoothed lines if the data series is smoothed.</p>

 <div id="chart02" style="height:300px; width:600px;"></div>
    <pre class="code brush:js"></pre>

<p>In this example, band data is supplied as an array of arrays of y values for the low and hi bands.  X values for the bands are taken from the x values of the series.  The band data is of the form:  [ [y low 1, y hi 1], [y low 2, y hi 2], ... ] and there must be a corresponding array of low/hi y values for each x value in the data series.</p>

 <div id="chart1" style="height:300px; width:600px;"></div>
    <pre class="code brush:js"></pre>

<p>The band data can also be supplied as an array of [low y values], [hi y values].  In this case there must also be an equal number of low y values and hi y values as there are data points in the series.  X values for the low and hi bands will be taken from the series data.  Additionally, the order of low/hi values does not matter as long as they are consistent.  jqPlot will figure out which is the low values and which are the high values.</p>

 <div id="chart2" style="height:300px; width:600px;"></div>
    <pre class="code brush:js"></pre>

<p>Band data does not have to be provided.  By default, jqPlot will compute +/- 3% band intervals if the "rendererOptions: { bands: { show: true } }" option is set.  The band intervals can be customized as well through the "rendererOptions: { bands: { interval: [number|string|arry] } }" option.  Valid intervals are:</p>

<ul>
<li> '1.7' - will add bands at y +/- 1.7 above and below the line.</li>
<li> '10%' - will compute +/- 10% interval bands.</li>
<li> [3, '-10%'] - will add bands at y + 3 and y - 10% above and below the line.</li>
</ul>

<p>Examples of such interval specifications are shown below:</p>

 <div id="chart3" style="height:300px; width:600px;"></div>
    <pre class="code brush:js"></pre>
 <div id="chart4" style="height:300px; width:600px;"></div>
    <pre class="code brush:js"></pre>

 <div id="chart5" style="height:300px; width:600px;"></div>
    <pre class="code brush:js"></pre>
    
<p>You can also customize the fill color of the bands and turn on/off band lines.  By default, bands respond to the mouse over event, but they can be set to respond to mouse down as well.</p>
 <div id="chart6" style="height:300px; width:600px;"></div>
    <pre class="code brush:js"></pre>

<p>Note, the plots on this page all extend the following pre-defined theme:</p>

    <pre class="code brush:js"></pre>


<script class="code" type="text/javascript">
$(document).ready(function(){
    // Band data in arrays of [x,y] values.
    bdat = [[['7/1/2011', 8], ['7/2/2011', 9], ['7/3/2011', 8], ['7/4/2011', 13], ['7/5/2011', 11], ['7/6/2011', 13]], 
    [['7/1/2011', 12], ['7/2/2011', 13], ['7/3/2011', 12], ['7/4/2011', 17], ['7/5/2011', 15], ['7/6/2011', 17]]];
    
    dat = [['7/1/2011', 10], ['7/2/2011', 11], ['7/3/2011', 10], ['7/4/2011', 15], ['7/5/2011', 13], ['7/6/2011', 15]];

    plot01 = $.jqplot('chart01', [dat], $.extend(true, {}, myTheme, {
        series: [{
            rendererOptions: {
                bandData: bdat
            }
        }],
        axes: {
            xaxis: {
                renderer: $.jqplot.DateAxisRenderer,
                min: '7/1/2011',
                max: '7/6/2011',
                tickInterval: '1 day'
            }
        }
    }));
});
</script>

<script class="code" type="text/javascript">
$(document).ready(function(){
    // Band data in arrays of [x,y] values.
    // Here the low band line (1st array) has 5 points and the hi band line has 4 points.
    bdat = [[['7/1/2011', 9], ['7/3/2011', 7], ['7/4/2011', 13], ['7/5/2011', 11], ['7/6/2011', 13]], 
    [['7/1/2011', 12], ['7/3/2011', 14], ['7/4/2011', 18], ['7/6/2011', 16]]];
    
    dat = [['7/1/2011', 10], ['7/2/2011', 11], ['7/3/2011', 10], ['7/4/2011', 15], ['7/5/2011', 13], ['7/6/2011', 15]];

    plot02 = $.jqplot('chart02', [dat], $.extend(true, {}, myTheme, {
        series: [{
            rendererOptions: {
                bandData: bdat,

                // turn on smoothing
                smooth: true
            }
        }],
        axes: {
            xaxis: {
                renderer: $.jqplot.DateAxisRenderer,
                min: '7/1/2011',
                max: '7/6/2011',
                tickInterval: '1 day'
            }
        }
    }));
});
</script>

<script class="code" type="text/javascript">
$(document).ready(function(){
    // data points for line.
    dat = [[0, 10], [1, 11], [2, 10], [3, 15], [4, 13], [5, 15]];

    // band data in [[low_y_1, hi_y_1], [low_y_2, hi_y_2],...] format
    bdat = [[7, 13], [8, 14], [7, 13], [12, 18], [10, 16], [12, 18]];

    plot1 = $.jqplot('chart1', [dat], $.extend(true, {}, myTheme, {
        series: [{
            rendererOptions: {
                // Set the band data on the series.
                // Bands will be turned on automatically if
                // valid band data is present.
                bandData: bdat,
                smooth: true
            }
        }]
    }));
});

</script>


<script class="code" type="text/javascript">

$(document).ready(function(){
    // here band data specified as an array of [low y values] and [hi y values]
    bdat = [[7, 8, 7, 12, 10, 12], [13, 14, 13, 18, 16, 18]];

    // Same plot as before with different band data specification and smoothed lines.
    plot2 = $.jqplot('chart2', [dat], $.extend(true, {}, myTheme, {
        series: [
        {
            rendererOptions: {
                bandData: bdat,
                smooth: true
            }
        }]
    }));
});

</script>

<script class="code" type="text/javascript">
$(document).ready(function(){
    plot3 = $.jqplot('chart3', [dat], $.extend(true, {}, myTheme, {
        series: [{
            rendererOptions: {
                bands: {
                    // draw bands at 1.7 "units" above and below line.
                    interval: 1.7
                },
                smooth: true
            }
        }]
    }));
});

</script>

<script class="code" type="text/javascript">
$(document).ready(function(){
    plot4 = $.jqplot('chart4', [dat], $.extend(true, {}, myTheme, {
        series: [{
            rendererOptions: {
                bands: {
                    // draw interval at 10% above and below line.
                    interval: '10%'
                },
                smooth: true
            }
        }]
    }));
});
</script>

<script class="code" type="text/javascript">
$(document).ready(function(){
    plot5 = $.jqplot('chart5', [dat], $.extend(true, {}, myTheme, {
        series: [{
            rendererOptions: {
                bands: {
                    // draw interval at 3 units above and 10% below line.
                    interval: [3, '-10%']
                },
                smooth: true
            }
        }]
    }));
});
</script>

<script class="code" type="text/javascript">
$(document).ready(function(){
    plot6 = $.jqplot('chart6', [dat], $.extend(true, {}, myTheme, {
        series: [{
            rendererOptions: {
                bands: {
                    // draw interval at 3 units above and 10% below line.
                    interval: 4,
                    fillColor: 'rgba(198, 88, 88, 0.6)',
                    showLines: true
                },

                // highlight the band on mouse down, not on mouse over.
                highlightMouseDown: true,
                smooth: true
            }
        }]
    }));
});
</script>

<script class="code" type="text/javascript">
///////
// A default set of reusable plot options.  Note that line
// smoothing is turned on.  Bands will be drawn with the same 
// smoothing as the line.
//////
myTheme = {
  grid: {
      drawBorder: false,
      shadow: false,
      background: 'rgba(255, 255, 255, 0.0)'
  },
  seriesDefaults: {
    shadow: false,
    showMarker: false
  },
  axes: {
      xaxis: {
          pad: 1.0,
          tickOptions: {
              showGridline: false
          }
      },
      yaxis: {
          pad: 1.05
      }
  }
};
</script>
<!-- End example scripts -->

<!-- Don't touch this! -->

<?php include "commonScripts.html" ?>

<!-- Additional plugins go here -->

    <script class="include" type="text/javascript" src="../src/plugins/jqplot.highlighter.js"></script>
    <script class="include" type="text/javascript" src="../src/plugins/jqplot.cursor.js"></script>
    <script class="include" type="text/javascript" src="../src/plugins/jqplot.pointLabels.js"></script>
    <script class="include" type="text/javascript" src="../src/plugins/jqplot.dateAxisRenderer.js"></script>

<!-- End additional plugins -->

<?php include "closer.php"; ?>